package usluga.soap;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.concurrent.atomic.AtomicInteger;

import jakarta.jws.WebParam;
import jakarta.jws.WebResult;
import jakarta.jws.WebService;
import usluga.model.Dane;
import usluga.model.Osoba;

@WebService(wsdlLocation = "/WEB-INF/wsdl/UslugaService.wsdl",
        targetNamespace = "http://soap.pcz/",
        name = "Usluga",
        portName = "UslugaPort",
        serviceName = "UslugaService")
public class Usluga {
    private final AtomicInteger licznik = new AtomicInteger();
    private final List<Osoba> osoby = Collections.synchronizedList(new ArrayList<>());
    
    @WebResult(name="dane")
    public Dane pobierzDane(@WebParam(name="imie") String imie) {
        return new Dane(licznik.incrementAndGet(), "Witaj " + imie);
    }
    
    public void zarejestruj(@WebParam(name="osoba") Osoba osoba) {
        osoby.add(osoba);
    }
    
    @WebResult(name="osoba")
    public Osoba pobierzOsobe(@WebParam(name="nr") int nr) throws NoSuchElementException {
        synchronized(osoby) {            
            if(nr < osoby.size()) {
                return osoby.get(nr);
            } else {
                throw new NoSuchElementException("Nie ma osoby nr " + nr);
            }
        }
    }

}
